@@ -1,33 +1,16 @@
-
-
 createDistMat <-
-  function(ssn, predpts = NULL, o.write = FALSE, amongpreds = FALSE) {
+function(ssn, predpts = NULL, o.write = FALSE, amongpreds = FALSE) {
 
-  if(class(ssn)[1] != "SpatialStreamNetwork") stop("Input is not a SpatialStreamNetwork object")
-  ##start.time <- Sys.time()
+  #start.time <- Sys.time()
   if(amongpreds && (missing(predpts) || is.null(predpts)))
   {
 	stop("A named collection of prediction points must be specified via the predpts option when amongpreds is TRUE")
   }
-
-  ## Stop if distance folder exists, when o.write = FALSE ...
-  if(file.exists(file.path(ssn@path, "distance"))) {
-    if(o.write == FALSE) {
-        stop("Distance folder exists and o.write = FALSE")
-    } else { ## o.write = TRUE
-        ## Remove distance directory
-        unlink(file.path(ssn@path, "distance"), recursive = TRUE)
-        ## Create distance directory
-        dir.create(file.path(ssn@path, "distance"))
-    }
-  }
-
-  ## If distance folder does not exist...
+  ##Check to see whether distance folder exists...
   if (!file.exists(file.path(ssn@path, "distance"))) {
     dir.create(file.path(ssn@path, "distance"))
   }
-
-  ## Check whether an observation folder exists
+  ##And then whether an observation folder exists
   if (!file.exists(file.path(ssn@path, "distance", "obs"))) {
     dir.create(file.path(ssn@path, "distance", "obs"))
   }
@@ -186,6 +169,7 @@ createDistMat <-
           ob.i_by_locID$locID <- as.numeric(ob.i_by_locID$locID)
           ob.j_reordering <- order(ob.i_by_locID$pid)
 
+
           locID.old <- -1
           ind.dup <- !duplicated(ob.i_by_locID$locID)
 
@@ -267,7 +251,7 @@ createDistMat <-
             }
           } else {
             ## add column to pred sites
-            if (!is.null(predpts) && pred.site.no > 0) {
+            if (!is.null(predpts)) {
               current_distance_matrix_a[paste(pid.i),]<- current_distance_matrix_a[paste(pid.old),]
               current_distance_matrix_b[,paste(pid.i)]<- current_distance_matrix_b[,paste(pid.old)]}
           }
